def make_document(s):
    a = ''
    a += '\\documentclass{article}\n'
    a += '\\usepackage{graphicx}\n'
    a += '\\graphicspath{ {./images/} }'
    a += '\\begin{document}\n'
    a += s
    a += '\\end{document}'
    return a

def generate_table(arr):
    s = ''
    t = len(arr[0])
    s += '\\begin{tabular}{ '
    s += '| '
    for i in range(t):
        s += 'c | '
    s += '}\n'
    for i in range(len(arr)):
        s += '\t'
        for j in range(len(arr[i])):
            s += str(arr[i][j])
            if j != len(arr[i]) - 1:
                s += ' & '
        if i != len(arr) - 1:
            s += ' \\\\\n'
        else:
            s += '\n'
    s += '\\end{tabular}\n'
    return s

def generate_image(image):
    s = ''
    s += f'\\includegraphics[scale=0.15]{{{image}}}\n'
    return s


import subprocess

tex_file = "table_image"

try:
    subprocess.check_call(["pdflatex", f"{tex_file}.tex"])
except subprocess.CalledProcessError as e:
    print(f"Error: {e}")

subprocess.call(['rm', f'{tex_file}.log'])
subprocess.call(['rm', f'{tex_file}.aux'])


from generator import generate_table, make_document, generate_image
with open('/Users/nikitakocherin/workspace/python_course/hw_2/table_image.tex', 'w') as f:
    s = generate_table([[1, 2, 3, 4], [1, 2, 3, 4]])
    i = generate_image('spb_st_isaacs_2.jpg')
    s = s + i
    s = make_document(s)
    f.write(s)